@@ -1,4 +1,4 @@
-/* $OpenBSD: x509cset.c,v 1.8 2014/07/11 08:44:49 jsing Exp $ */
+/* $OpenBSD: x509cset.c,v 1.11 2015/09/30 17:49:59 jsing Exp $ */
 /* Written by Dr Stephen N Henson (steve@openssl.org) for the OpenSSL
  * project 2001.
  */
@@ -69,7 +69,7 @@ X509_CRL_set_version(X509_CRL *x, long version)
 	if (x == NULL)
 		return (0);
 	if (x->crl->version == NULL) {
-		if ((x->crl->version = M_ASN1_INTEGER_new()) == NULL)
+		if ((x->crl->version = ASN1_INTEGER_new()) == NULL)
 			return (0);
 	}
 	return (ASN1_INTEGER_set(x->crl->version, version));
@@ -94,7 +94,7 @@ X509_CRL_set_lastUpdate(X509_CRL *x, const ASN1_TIME *tm)
 	if (in != tm) {
 		in = ASN1_STRING_dup(tm);
 		if (in != NULL) {
-			M_ASN1_TIME_free(x->crl->lastUpdate);
+			ASN1_TIME_free(x->crl->lastUpdate);
 			x->crl->lastUpdate = in;
 		}
 	}
@@ -112,7 +112,7 @@ X509_CRL_set_nextUpdate(X509_CRL *x, const ASN1_TIME *tm)
 	if (in != tm) {
 		in = ASN1_STRING_dup(tm);
 		if (in != NULL) {
-			M_ASN1_TIME_free(x->crl->nextUpdate);
+			ASN1_TIME_free(x->crl->nextUpdate);
 			x->crl->nextUpdate = in;
 		}
 	}
@@ -147,7 +147,7 @@ X509_REVOKED_set_revocationDate(X509_REVOKED *x, ASN1_TIME *tm)
 	if (in != tm) {
 		in = ASN1_STRING_dup(tm);
 		if (in != NULL) {
-			M_ASN1_TIME_free(x->revocationDate);
+			ASN1_TIME_free(x->revocationDate);
 			x->revocationDate = in;
 		}
 	}
@@ -163,9 +163,9 @@ X509_REVOKED_set_serialNumber(X509_REVOKED *x, ASN1_INTEGER *serial)
 		return (0);
 	in = x->serialNumber;
 	if (in != serial) {
-		in = ASN1_STRING_dup(serial);
+		in = ASN1_INTEGER_dup(serial);
 		if (in != NULL) {
-			M_ASN1_INTEGER_free(x->serialNumber);
+			ASN1_INTEGER_free(x->serialNumber);
 			x->serialNumber = in;
 		}
 	}
