@@ -1,4 +1,4 @@
-/* $OpenBSD: s3_lib.c,v 1.132 2017/01/26 10:40:21 beck Exp $ */
+/* $OpenBSD: s3_lib.c,v 1.138 2017/03/10 16:03:27 jsing Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -1722,7 +1722,7 @@ ssl3_handshake_msg_finish(SSL *s, unsigned int len)
 	s->internal->init_off = 0;
 
 	if (SSL_IS_DTLS(s)) {
-		dtls1_set_message_header(s, d, msg_type, len, 0, len);
+		dtls1_set_message_header(s, msg_type, len, 0, len);
 		dtls1_buffer_message(s, 0);
 	}
 }
@@ -1785,7 +1785,7 @@ ssl3_handshake_msg_finish_cbb(SSL *s, CBB *handshake)
 
 		len = outlen - ssl3_handshake_msg_hdr_len(s);
 
-		dtls1_set_message_header(s, data, msg_type, len, 0, len);
+		dtls1_set_message_header(s, msg_type, len, 0, len);
 		dtls1_buffer_message(s, 0);
 	}
 
@@ -1839,8 +1839,11 @@ ssl3_free(SSL *s)
 	free(S3I(s)->tmp.x25519);
 
 	sk_X509_NAME_pop_free(S3I(s)->tmp.ca_names, X509_NAME_free);
+
 	BIO_free(S3I(s)->handshake_buffer);
-	tls1_free_digest_list(s);
+
+	tls1_handshake_hash_free(s);
+
 	free(S3I(s)->alpn_selected);
 
 	explicit_bzero(S3I(s), sizeof(*S3I(s)));
@@ -1880,7 +1883,7 @@ ssl3_clear(SSL *s)
 	BIO_free(S3I(s)->handshake_buffer);
 	S3I(s)->handshake_buffer = NULL;
 
-	tls1_free_digest_list(s);
+	tls1_handshake_hash_free(s);
 
 	free(S3I(s)->alpn_selected);
 	S3I(s)->alpn_selected = NULL;
@@ -1980,7 +1983,7 @@ ssl3_ctrl(SSL *s, int cmd, long larg, void *parg)
 
 	if (cmd == SSL_CTRL_SET_TMP_DH || cmd == SSL_CTRL_SET_TMP_DH_CB) {
 		if (!ssl_cert_inst(&s->cert)) {
-			SSLerror(ERR_R_MALLOC_FAILURE);
+			SSLerror(s, ERR_R_MALLOC_FAILURE);
 			return (0);
 		}
 	}
@@ -2009,17 +2012,17 @@ ssl3_ctrl(SSL *s, int cmd, long larg, void *parg)
 		break;
 	case SSL_CTRL_SET_TMP_RSA:
 	case SSL_CTRL_SET_TMP_RSA_CB:
-		SSLerror(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
+		SSLerror(s, ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
 		break;
 	case SSL_CTRL_SET_TMP_DH:
 		{
 			DH *dh = (DH *)parg;
 			if (dh == NULL) {
-				SSLerror(ERR_R_PASSED_NULL_PARAMETER);
+				SSLerror(s, ERR_R_PASSED_NULL_PARAMETER);
 				return (ret);
 			}
 			if ((dh = DHparams_dup(dh)) == NULL) {
-				SSLerror(ERR_R_DH_LIB);
+				SSLerror(s, ERR_R_DH_LIB);
 				return (ret);
 			}
 			DH_free(s->cert->dh_tmp);
@@ -2029,7 +2032,7 @@ ssl3_ctrl(SSL *s, int cmd, long larg, void *parg)
 		break;
 
 	case SSL_CTRL_SET_TMP_DH_CB:
-		SSLerror(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
+		SSLerror(s, ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
 		return (ret);
 
 	case SSL_CTRL_SET_DH_AUTO:
@@ -2041,18 +2044,18 @@ ssl3_ctrl(SSL *s, int cmd, long larg, void *parg)
 			EC_KEY *ecdh = NULL;
 
 			if (parg == NULL) {
-				SSLerror(ERR_R_PASSED_NULL_PARAMETER);
+				SSLerror(s, ERR_R_PASSED_NULL_PARAMETER);
 				return (ret);
 			}
 			if (!EC_KEY_up_ref((EC_KEY *)parg)) {
-				SSLerror(ERR_R_ECDH_LIB);
+				SSLerror(s, ERR_R_ECDH_LIB);
 				return (ret);
 			}
 			ecdh = (EC_KEY *)parg;
 			if (!(s->internal->options & SSL_OP_SINGLE_ECDH_USE)) {
 				if (!EC_KEY_generate_key(ecdh)) {
 					EC_KEY_free(ecdh);
-					SSLerror(ERR_R_ECDH_LIB);
+					SSLerror(s, ERR_R_ECDH_LIB);
 					return (ret);
 				}
 			}
@@ -2063,7 +2066,7 @@ ssl3_ctrl(SSL *s, int cmd, long larg, void *parg)
 		break;
 	case SSL_CTRL_SET_TMP_ECDH_CB:
 		{
-			SSLerror(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
+			SSLerror(s, ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
 			return (ret);
 		}
 		break;
@@ -2076,16 +2079,16 @@ ssl3_ctrl(SSL *s, int cmd, long larg, void *parg)
 			if (parg == NULL)
 				break;
 			if (strlen((char *)parg) > TLSEXT_MAXLEN_host_name) {
-				SSLerror(SSL_R_SSL3_EXT_INVALID_SERVERNAME);
+				SSLerror(s, SSL_R_SSL3_EXT_INVALID_SERVERNAME);
 				return 0;
 			}
 			if ((s->tlsext_hostname = strdup((char *)parg))
 			    == NULL) {
-				SSLerror(ERR_R_INTERNAL_ERROR);
+				SSLerror(s, ERR_R_INTERNAL_ERROR);
 				return 0;
 			}
 		} else {
-			SSLerror(SSL_R_SSL3_EXT_INVALID_SERVERNAME_TYPE);
+			SSLerror(s, SSL_R_SSL3_EXT_INVALID_SERVERNAME_TYPE);
 			return 0;
 		}
 		break;
@@ -2135,6 +2138,12 @@ ssl3_ctrl(SSL *s, int cmd, long larg, void *parg)
 		ret = 1;
 		break;
 
+	case SSL_CTRL_SET_GROUPS:
+		return SSL_set1_groups(s, parg, larg);
+
+	case SSL_CTRL_SET_GROUPS_LIST:
+		return SSL_set1_groups_list(s, parg);
+
 	case SSL_CTRL_GET_SERVER_TMP_KEY:
 		ret = ssl_ctrl_get_server_tmp_key(s, parg);
 		break;
@@ -2167,14 +2176,14 @@ ssl3_callback_ctrl(SSL *s, int cmd, void (*fp)(void))
 
 	if (cmd == SSL_CTRL_SET_TMP_DH_CB) {
 		if (!ssl_cert_inst(&s->cert)) {
-			SSLerror(ERR_R_MALLOC_FAILURE);
+			SSLerror(s, ERR_R_MALLOC_FAILURE);
 			return (0);
 		}
 	}
 
 	switch (cmd) {
 	case SSL_CTRL_SET_TMP_RSA_CB:
-		SSLerror(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
+		SSLerror(s, ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
 		break;
 	case SSL_CTRL_SET_TMP_DH_CB:
 		s->cert->dh_tmp_cb = (DH *(*)(SSL *, int, int))fp;
@@ -2204,7 +2213,7 @@ ssl3_ctx_ctrl(SSL_CTX *ctx, int cmd, long larg, void *parg)
 		return (0);
 	case SSL_CTRL_SET_TMP_RSA:
 	case SSL_CTRL_SET_TMP_RSA_CB:
-		SSLerror(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
+		SSLerrorx(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
 		return (0);
 	case SSL_CTRL_SET_TMP_DH:
 		{
@@ -2212,7 +2221,7 @@ ssl3_ctx_ctrl(SSL_CTX *ctx, int cmd, long larg, void *parg)
 
 			dh = (DH *)parg;
 			if ((new = DHparams_dup(dh)) == NULL) {
-				SSLerror(ERR_R_DH_LIB);
+				SSLerrorx(ERR_R_DH_LIB);
 				return 0;
 			}
 			DH_free(cert->dh_tmp);
@@ -2222,7 +2231,7 @@ ssl3_ctx_ctrl(SSL_CTX *ctx, int cmd, long larg, void *parg)
 		/*break; */
 
 	case SSL_CTRL_SET_TMP_DH_CB:
-		SSLerror(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
+		SSLerrorx(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
 		return (0);
 
 	case SSL_CTRL_SET_DH_AUTO:
@@ -2234,18 +2243,18 @@ ssl3_ctx_ctrl(SSL_CTX *ctx, int cmd, long larg, void *parg)
 			EC_KEY *ecdh = NULL;
 
 			if (parg == NULL) {
-				SSLerror(ERR_R_ECDH_LIB);
+				SSLerrorx(ERR_R_ECDH_LIB);
 				return 0;
 			}
 			ecdh = EC_KEY_dup((EC_KEY *)parg);
 			if (ecdh == NULL) {
-				SSLerror(ERR_R_EC_LIB);
+				SSLerrorx(ERR_R_EC_LIB);
 				return 0;
 			}
 			if (!(ctx->internal->options & SSL_OP_SINGLE_ECDH_USE)) {
 				if (!EC_KEY_generate_key(ecdh)) {
 					EC_KEY_free(ecdh);
-					SSLerror(ERR_R_ECDH_LIB);
+					SSLerrorx(ERR_R_ECDH_LIB);
 					return 0;
 				}
 			}
@@ -2257,7 +2266,7 @@ ssl3_ctx_ctrl(SSL_CTX *ctx, int cmd, long larg, void *parg)
 		/* break; */
 	case SSL_CTRL_SET_TMP_ECDH_CB:
 		{
-			SSLerror(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
+			SSLerrorx(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
 			return (0);
 		}
 		break;
@@ -2271,7 +2280,7 @@ ssl3_ctx_ctrl(SSL_CTX *ctx, int cmd, long larg, void *parg)
 			if (!keys)
 				return 48;
 			if (larg != 48) {
-				SSLerror(SSL_R_INVALID_TICKET_KEYS_LENGTH);
+				SSLerrorx(SSL_R_INVALID_TICKET_KEYS_LENGTH);
 				return 0;
 			}
 			if (cmd == SSL_CTRL_SET_TLSEXT_TICKET_KEYS) {
@@ -2315,6 +2324,12 @@ ssl3_ctx_ctrl(SSL_CTX *ctx, int cmd, long larg, void *parg)
 		ctx->extra_certs = NULL;
 		break;
 
+	case SSL_CTRL_SET_GROUPS:
+		return SSL_CTX_set1_groups(ctx, parg, larg);
+
+	case SSL_CTRL_SET_GROUPS_LIST:
+		return SSL_CTX_set1_groups_list(ctx, parg);
+
 	default:
 		return (0);
 	}
@@ -2344,7 +2359,7 @@ ssl3_ctx_callback_ctrl(SSL_CTX *ctx, int cmd, void (*fp)(void))
 
 	switch (cmd) {
 	case SSL_CTRL_SET_TMP_RSA_CB:
-		SSLerror(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
+		SSLerrorx(ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
 		return (0);
 	case SSL_CTRL_SET_TMP_DH_CB:
 		cert->dh_tmp_cb = (DH *(*)(SSL *, int, int))fp;
